#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 terminal-size
version:              0.3.2.1
visibility:           public
id:                   terminal-size-0.3.2.1-8LMlp57ywuCIM7VIh4tqn1
key:                  terminal-size-0.3.2.1-8LMlp57ywuCIM7VIh4tqn1
license:              BSD-3-Clause
maintainer:           matvey.aksenov@gmail.com
author:               Andreas Hammar, Matvey Aksenov
synopsis:             Get terminal window height and width
description:
    Get terminal window height and width without ncurses dependency.

category:             System
abi:                  e301438f282e9076865ed7e1ac133fe9
exposed:              True
exposed-modules:      System.Console.Terminal.Size
hidden-modules:
    System.Console.Terminal.Common System.Console.Terminal.Posix

import-dirs:          /usr/lib/ghc-8.10.5/site-local/terminal-size-0.3.2.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/terminal-size-0.3.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/terminal-size-0.3.2.1
hs-libraries:         HSterminal-size-0.3.2.1-8LMlp57ywuCIM7VIh4tqn1
depends:              base-4.14.2.0
haddock-interfaces:
    /usr/share/doc/haskell-terminal-size/html/terminal-size.haddock

haddock-html:         /usr/share/doc/haskell-terminal-size/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

